.. :changelog:

Release History
===============

0.0.10
++++++
* Minor fixes.

0.0.9
++++++
* Added detailed errors to validation response when creating cluster.
* Fix missing client issue with several commands.

0.0.8
++++++
* Update for CLI core changes.

0.0.7
+++++
* Minor fixes.

0.0.6
+++++
* Minor fixes.

0.0.5
+++++
* minor fixes

0.0.4 (2017-09-22)
++++++++++++++++++
* minor fixes

0.0.3 (2017-08-31)
++++++++++++++++++
* minor fixes

0.0.2 (2017-08-28)
++++++++++++++++++

* Preview release.
